==> ds-sdk-mini-0.0.4.tar.gz: ds-sdk-mini-0.0.4/DeepSecurity/Administrators.py <==
#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.
#import connect
#import config

class Administrators:
    def __init__(self, config, connection):
        self._config=config
        self._connection = connection
    ##Administrators
    def listAdministrators(self):
        return self._connection.get(url='/administrators')
    def createAdministrator(self, payload):
        return self._connection.post(url='/administrators', data=payload)
    def administrator(self, adminID):
        return self._connection.get(url='/administrators/' + str(adminID))
    def modifyAdministrator(self, adminID, payload):
        return self._connection.post(url='/administrators/' + str(adminID), data=payload)
    def deleteAdministrator(self, adminID):
        return self._connection.delete(url='/administrators/' + str(adminID))
    def searchAdministrators(self, payload):
        return self._connection.post(url='/administrators/search', data=payload)
    #Roles
    def listAdministratorRoles(self):
        return self._connection.get(url='/roles')
    def createAdministratorRole(self, payload):
        return self._connection.post(url='/roles', data=payload)
    def searchAdministratorRole(self, payload):
        return self._connection.post(url='/roles/search', data=payload)
    def administratorRole(self, roleID):
        return self._connection.get(url='/roles/' + str(roleID))
    def modifyadministratorRole(self, roleID, payload):
        return self._connection.post(url='/roles/' + str(roleID), data=payload)
    def deleteAdministratorRole(self, roleID):
        return self._connection.delete(url='/roles/' + str(roleID))

==> ds-sdk-mini-0.0.9.tar.gz: ds-sdk-mini-0.0.9/DeepSecurity/Administrators.py <==
#  Copyright (c) 2020. Brendan Johnson. All Rights Reserved.
#import connect
#import config

class Administrators:
    def __init__(self, config, connection):
        self._config=config
        self._connection = connection
    ##Administrators
    def list(self):
        return self._connection.get(url='/administrators')
    def create(self, payload):
        return self._connection.post(url='/administrators', data=payload)
    def describe(self, adminID):
        return self._connection.get(url='/administrators/' + str(adminID))
    def modify(self, adminID, payload):
        return self._connection.post(url='/administrators/' + str(adminID), data=payload)
    def delete(self, adminID):
        return self._connection.delete(url='/administrators/' + str(adminID))
    def search(self, payload):
        return self._connection.post(url='/administrators/search', data=payload)
    #Roles
    def listRoles(self):
        return self._connection.get(url='/roles')
    def createRole(self, payload):
        return self._connection.post(url='/roles', data=payload)
    def searchRole(self, payload):
        return self._connection.post(url='/roles/search', data=payload)
    def describeRole(self, roleID):
        return self._connection.get(url='/roles/' + str(roleID))
    def modifyRole(self, roleID, payload):
        return self._connection.post(url='/roles/' + str(roleID), data=payload)
    def deleteRole(self, roleID):
        return self._connection.delete(url='/roles/' + str(roleID))
